@@ -36,8 +36,8 @@ const Element::AttributeList Element::get_attributes() const
   return const_cast<Element*>(this)->get_attributes();
 }
 
-Attribute* Element::get_attribute(const std::string& name,
-                                  const std::string& ns_prefix) const
+Attribute* Element::get_attribute(const Glib::ustring& name,
+                                  const Glib::ustring& ns_prefix) const
 {
   if (ns_prefix.empty())
   {
@@ -49,20 +49,17 @@ Attribute* Element::get_attribute(const std::string& name,
   }
   else
   {
-    std::string ns_uri = get_namespace_uri_for_prefix(ns_prefix);  
+    Glib::ustring ns_uri = get_namespace_uri_for_prefix(ns_prefix);  
     xmlAttr* attr = xmlHasNsProp(const_cast<xmlNode*>(cobj()), (const xmlChar*)name.c_str(),
                                  (const xmlChar*)ns_uri.c_str());
-	if( attr )
-	{
-      return reinterpret_cast<Attribute*>(attr->_private);
-	}
+    return reinterpret_cast<Attribute*>(attr->_private);
   }
 
   return 0;
 }
 
-Attribute* Element::set_attribute(const std::string& name, const std::string& value,
-                                  const std::string& ns_prefix)
+Attribute* Element::set_attribute(const Glib::ustring& name, const Glib::ustring& value,
+                                  const Glib::ustring& ns_prefix)
 {
   xmlAttr* attr = 0;
 
@@ -93,7 +90,7 @@ Attribute* Element::set_attribute(const std::string& name, const std::string& va
     return 0;
 }
 
-void Element::remove_attribute(const std::string& name, const std::string& ns_prefix)
+void Element::remove_attribute(const Glib::ustring& name, const Glib::ustring& ns_prefix)
 {
   if (ns_prefix.empty())
     xmlUnsetProp(cobj(), (const xmlChar*)name.c_str());
@@ -126,7 +123,7 @@ TextNode* Element::get_child_text()
   return 0;
 }
 
-void Element::set_child_text(const std::string& content)
+void Element::set_child_text(const Glib::ustring& content)
 {
   TextNode* node = get_child_text();
   if(node)
@@ -135,7 +132,7 @@ void Element::set_child_text(const std::string& content)
     add_child_text(content);
 }
 
-TextNode* Element::add_child_text(const std::string& content)
+TextNode* Element::add_child_text(const Glib::ustring& content)
 {
   if(cobj()->type == XML_ELEMENT_NODE)
   {
@@ -151,7 +148,7 @@ bool Element::has_child_text() const
   return get_child_text() != 0;
 }
 
-void Element::set_namespace_declaration(const std::string& ns_uri, const std::string& ns_prefix)
+void Element::set_namespace_declaration(const Glib::ustring& ns_uri, const Glib::ustring& ns_prefix)
 {
   //Create a new namespace declaration for this element:
   xmlNewNs(cobj(), (const xmlChar*)(ns_uri.empty() ? 0 : ns_uri.c_str()),
@@ -159,9 +156,9 @@ void Element::set_namespace_declaration(const std::string& ns_uri, const std::st
   //We ignore the returned xmlNS*. Hopefully this is owned by the node. murrayc.
 }
 
-std::string Element::get_namespace_uri_for_prefix(const std::string& ns_prefix) const
+Glib::ustring Element::get_namespace_uri_for_prefix(const Glib::ustring& ns_prefix) const
 {
-  std::string result;
+  Glib::ustring result;
   
   //Find the namespace:
   const xmlNs* ns = xmlSearchNs( cobj()->doc, const_cast<xmlNode*>(cobj()), (xmlChar*)ns_prefix.c_str() );
@@ -176,7 +173,7 @@ std::string Element::get_namespace_uri_for_prefix(const std::string& ns_prefix)
 }
 
 
-CommentNode* Element::add_child_comment(const std::string& content)
+CommentNode* Element::add_child_comment(const Glib::ustring& content)
 {
   xmlNode* node = xmlNewComment((const xmlChar*)content.c_str());
   xmlAddChild(cobj(), node);
